@@ -15,13 +15,14 @@ class KDFTopLevel : public KXmlGuiWindow
 {
     Q_OBJECT
 
-    public:
-        explicit KDFTopLevel(QWidget *parent= nullptr);
-        ~KDFTopLevel() override { }
+public:
+    explicit KDFTopLevel(QWidget *parent = nullptr);
+    ~KDFTopLevel() override
+    {
+    }
 
-    protected:
-        KDFWidget* kdf;
+protected:
+    KDFWidget *kdf;
 };
 
 #endif
-
